==> docfbe_2_2_31_55.zip: docfbe_2_2_31_55/source/TCFbEOutputFormatter.h <==
/*
    TCFbEOutputFormatter.h    June 6, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#ifndef TCFbEOutputFormatterH
#define TCFbEOutputFormatterH
//---------------------------------------------------------------------------
#include <stdio.h>
#include <system.hpp>
#include <SysUtils.hpp>

#include "TCFbECommandLineParser.h"
#include "TCFbEOutputCash.h"
//---------------------------------------------------------------------------
class TCFbEOutputFormatter : public TObject
{
public:
    virtual __fastcall TCFbEOutputFormatter(TCFbECommandLineParser* Parser, TCFbEOutputCash* OutputCash, bool IsVerbose=false);    // RXgN^
    __fastcall ~TCFbEOutputFormatter();    // fXgN^

    virtual AnsiString __fastcall GetOutputString(void);
    virtual void __fastcall SaveOutputStringTo(TFileName FileName);    // OutputString  FileName ̃t@Cɕۑ

protected:
    TCFbECommandLineParser*    Parser;
    TCFbEOutputCash*    OutputCash;
    TStringList*    FOutputStringList;
    virtual void __fastcall OutputHeader(void) = 0;    // wb_ this->FOutputStringList ɒǉDwb_KvłȂꍇ͂ return D
    virtual void __fastcall OutputBody(int TargetRowIndex) = 0;    // {fB this->FOutputStringList ɒǉD

private:

};
//---------------------------------------------------------------------------
#endif

==> docfbe_2_3_46_82.zip: docfbe_2_3_46_82/source/TCFbEOutputFormatter.h <==
/*
    TCFbEOutputFormatter.h    June 6, 2004.

    Copyright (C) 2003-2005 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#ifndef TCFbEOutputFormatterH
#define TCFbEOutputFormatterH
//---------------------------------------------------------------------------
#include <stdio.h>
#include <system.hpp>
#include <SysUtils.hpp>

#include "TCFbEDocfbeCommandLineParser.h"
#include "TCFbEOutputCache.h"
//---------------------------------------------------------------------------
class TCFbEOutputFormatter : public TObject
{
public:
    virtual __fastcall TCFbEOutputFormatter(TCFbEDocfbeCommandLineParser* Parser, TCFbEOutputCache* OutputCache, bool IsVerbose=false);    // RXgN^
    __fastcall ~TCFbEOutputFormatter();    // fXgN^

    virtual AnsiString __fastcall GetOutputString(void);
    virtual void __fastcall SaveOutputStringTo(TFileName FileName);    // OutputString  FileName ̃t@Cɕۑ

protected:
    TCFbEDocfbeCommandLineParser*    Parser;
    TCFbEOutputCache*    OutputCache;
    TStringList*    FOutputStringList;
    virtual void __fastcall OutputHeader(void) = 0;    // wb_ this->FOutputStringList ɒǉDwb_KvłȂꍇ͂ return D
    virtual void __fastcall OutputBody(int TargetRowIndex) = 0;    // {fB this->FOutputStringList ɒǉD

private:

};
//---------------------------------------------------------------------------
#endif
